#!/usr/bin/perl
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: Savannah.pm,v 1.16 2004/09/24 11:36:54 yeupou Exp $
#
# Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

##
## Basic module that load any convenient submodules.
##

use strict;
use Term::ANSIColor qw(:constants);
use DBI;
use POSIX qw(strftime);

# Load modules
use Savannah::Version;
use Savannah::Conf;
use Savannah::DB;
use Savannah::Mail;
use Savannah::User;
use Savannah::Groups;

return "true";

